@@ -14,7 +14,7 @@ use Validation::Class::Fields;
 use Validation::Class::Errors;
 use Validation::Class::Util;
 
-our $VERSION = '7.900011'; # VERSION
+our $VERSION = '7.900012'; # VERSION
 
 use Hash::Flatten 'flatten', 'unflatten';
 use Module::Runtime 'use_module';
@@ -861,14 +861,12 @@ sub normalize {
 
     # alias checking, ... for duplicate aliases, etc
 
-    my $fieldtree = {};
-    my $aliastree = {};
+    my $mapper = {};
+    my @fields = $self->fields->keys;
 
-    foreach my $pair ($self->fields->pairs) {
+    foreach my $name (@fields) {
 
-        my($name, $field)  = @{$pair}{'key', 'value'};
-
-        $fieldtree->{$name} = $name; # just a counter
+        my $field = $self->fields->get($name);
 
         if (defined $field->{alias}) {
 
@@ -877,31 +875,29 @@ sub normalize {
 
             foreach my $alias (@{$aliases}) {
 
-                if ($aliastree->{$alias}) {
+                if ($mapper->{$alias}) {
 
-                    my $error = qq(
-                        The field $field contains the alias $alias which is
-                        also defined in the field $aliastree->{$alias}
-                    );
+                    my $error =
+                        qq(The field $name contains the alias $alias which is
+                        also an alias on the field $mapper->{$alias})
+                    ;
 
                     $self->throw_error($error);
 
                 }
-                elsif ($fieldtree->{$alias}) {
 
-                    my $error = qq(
-                        The field $field contains the alias $alias which is
-                        the name of an existing field
-                    );
+                if ($self->fields->has($alias)) {
+
+                    my $error =
+                        qq(The field $name contains the alias $alias which is
+                        the name of an existing field)
+                    ;
 
                     $self->throw_error($error);
 
                 }
-                else {
 
-                    $aliastree->{$alias} = $field;
-
-                }
+                $mapper->{$alias} = $name;
 
             }
 
@@ -1972,7 +1968,7 @@ Validation::Class::Prototype - Data Validation Engine for Validation::Class Clas
 
 =head1 VERSION
 
-version 7.900011
+version 7.900012
 
 =head1 DESCRIPTION
 
